Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(7217)

Unified Diff: chrome/browser/extensions/page_action_controller.h

Issue 10911105: Switch ScriptBadgeController and PageActionController to use WebContents. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/extensions/page_action_controller.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/extensions/page_action_controller.h
diff --git a/chrome/browser/extensions/page_action_controller.h b/chrome/browser/extensions/page_action_controller.h
index ab4097e3e93b0506e3eebeed8d34db41294d350a..1f711f616c3d7a712165ebc7f0139f21c36d3819 100644
--- a/chrome/browser/extensions/page_action_controller.h
+++ b/chrome/browser/extensions/page_action_controller.h
@@ -13,7 +13,6 @@
#include "content/public/browser/web_contents_observer.h"
class ExtensionService;
-class TabContents;
namespace extensions {
@@ -22,7 +21,7 @@ namespace extensions {
class PageActionController : public LocationBarController,
public content::WebContentsObserver {
public:
- explicit PageActionController(TabContents* tab_contents);
+ explicit PageActionController(content::WebContents* web_contents);
Aaron Boodman 2012/09/05 22:02:00 General comment. It is really important that all o
virtual ~PageActionController();
// LocationBarController implementation.
@@ -39,11 +38,9 @@ class PageActionController : public LocationBarController,
const content::FrameNavigateParams& params) OVERRIDE;
private:
// Gets the ExtensionService for |tab_contents_|.
ExtensionService* GetExtensionService() const;
- TabContents* tab_contents_;
-
DISALLOW_COPY_AND_ASSIGN(PageActionController);
};
« no previous file with comments | « no previous file | chrome/browser/extensions/page_action_controller.cc » ('j') | no next file with comments »
@@ -39,11 +38,9 @@ class PageActionController : public LocationBarController,
const content::FrameNavigateParams& params) OVERRIDE;
private:
- // Gets the ExtensionService for |tab_contents_|.
+ // Gets the ExtensionService for the web contents.
ExtensionService* GetExtensionService() const;

Powered by Google App Engine
This is Rietveld 408576698